@@ -23,7 +23,7 @@ Implementation Notes
 
 """
 
-__version__ = "2.27.0"
+__version__ = "2.28.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Text.git"
 
 import time
@@ -86,7 +86,7 @@ class ScrollingLabel(bitmap_label.Label):
         if force or self._last_animate_time + self.animate_time <= _now:
 
             if len(self.full_text) <= self.max_characters:
-                self.text = self.full_text
+                super()._set_text(self.full_text, self.scale)
                 self._last_animate_time = _now
                 return
 
@@ -106,8 +106,7 @@ class ScrollingLabel(bitmap_label.Label):
                 _showing_string = "{}{}".format(
                     _showing_string_start, _showing_string_end
                 )
-            self.text = _showing_string
-
+            super()._set_text(_showing_string, self.scale)
             self.current_index += 1
             self._last_animate_time = _now
 
@@ -144,3 +143,16 @@ class ScrollingLabel(bitmap_label.Label):
         self._full_text = new_text
         self.current_index = 0
         self.update()
+
+    @property
+    def text(self):
+        """The full text to be shown. If it's longer than ``max_characters`` then
+        scrolling will occur as needed.
+
+        :return str: The full text of this label.
+        """
+        return self.full_text
+
+    @text.setter
+    def text(self, new_text):
+        self.full_text = new_text
